==> paikalta-2023.2.10.tar.gz: paikalta-2023.2.10/README.md <==
# Paikalta

From the place (Finnish: paikalta) we derive the name.

[License: MIT](https://git.sr.ht/~sthagen/paikalta/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![downloads](https://pepy.tech/badge/paikalta/month)](https://pepy.tech/project/paikalta)
[![wheel](https://img.shields.io/pypi/wheel/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![supported-versions](https://img.shields.io/pypi/pyversions/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![supported-implementations](https://img.shields.io/pypi/implementation/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)

## Documentation

User and developer [documentation of paikalta](https://codes.dilettant.life/docs/paikalta).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of paikalta](https://todo.sr.ht/~sthagen/paikalta).

## Primary Source repository

The main source of `paikalta` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `paikalta` are:

* [on codeberg](https://codeberg.org/sthagen/paikalta) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/paikalta) - a collection of tools useful for software development.

## Acknowledgements

[Thomas Schmidt](https://github.com/tschmidtb51) provided the original source code as
script [`check.py`](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/test/filenames/check.py) and
test cases in `test/fixtures/upstream/` as contributions to the OASIS CSAF TC repository
below [/csaf_2.0/test/filenames/data](https://github.com/oasis-tcs/csaf/tree/master/csaf_2.0/test/filenames/data).

# Status

Experimental.

**Note**: The default branch is `default`.

==> paikalta-2023.6.18.tar.gz: paikalta-2023.6.18/README.md <==
# Paikalta

From the place (Finnish: paikalta) we derive the name.

[License: MIT](https://git.sr.ht/~sthagen/paikalta/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![downloads](https://pepy.tech/badge/paikalta/month)](https://pepy.tech/project/paikalta)
[![wheel](https://img.shields.io/pypi/wheel/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![supported-versions](https://img.shields.io/pypi/pyversions/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)
[![supported-implementations](https://img.shields.io/pypi/implementation/paikalta.svg?style=flat)](https://pypi.python.org/pypi/paikalta/)

## Documentation

User and developer [documentation of paikalta](https://codes.dilettant.life/docs/paikalta).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of paikalta](https://todo.sr.ht/~sthagen/paikalta).

## Primary Source repository

The main source of `paikalta` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `paikalta` are:

* [on codeberg](https://codeberg.org/sthagen/paikalta) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/paikalta) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Acknowledgements

[Thomas Schmidt](https://github.com/tschmidtb51) provided the original source code as
script [`check.py`](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/test/filenames/check.py) and
test cases in `test/fixtures/upstream/` as contributions to the OASIS CSAF TC repository
below [/csaf_2.0/test/filenames/data](https://github.com/oasis-tcs/csaf/tree/master/csaf_2.0/test/filenames/data).

# Status

Experimental.

**Note**: The default branch is `default`.
